# Python BioArch
[![CircleCI](https://circleci.com/gh/TheBiggerGuy/bioarch/tree/master.svg?style=svg)](https://circleci.com/gh/TheBiggerGuy/bioarch/tree/master)
[![codecov](https://codecov.io/gh/TheBiggerGuy/bioarch/branch/master/graph/badge.svg)](https://codecov.io/gh/TheBiggerGuy/bioarch)
[![Documentation Status](https://readthedocs.org/projects/bioarch/badge/?version=latest)](https://bioarch.readthedocs.io/en/latest/?badge=latest)
[![](https://img.shields.io/github/issues-raw/TheBiggerGuy/bioarch.svg)](https://github.com/TheBiggerGuy/bioarch/issues)
[![](https://tokei.rs/b1/github/TheBiggerGuy/bioarch)](https://github.com/TheBiggerGuy/bioarch)
[![PyPI version](https://badge.fury.io/py/bioarch.svg)](https://badge.fury.io/py/bioarch)

A Python bioarchaeology library to help with modelling data in the archaeology/bioarchaeology field.

* Code at https://github.com/TheBiggerGuy/bioarch
* PyPI at https://pypi.org/project/bioarch/
* Docs at https://bioarch.readthedocs.io/en/latest/
